@@ -151,9 +151,12 @@ class PostListDirective(Directive):
 
 
 class CheckFrontMatter(SphinxTransform):
-    """Check the doctree for frontmatter meant for a blog post.
+    """
+    Check the doctree for frontmatter meant for a blog post.
 
-    This is mutually-exclusive with the PostDirective. Only one much be used."""
+    This is mutually-exclusive with the PostDirective. Only one much be
+    used.
+    """
 
     # Priority before 880 so that it runs before the `doctree-read` event
     default_priority = 800
@@ -213,6 +216,7 @@ def purge_posts(app, env, docname):
 
     filename = os.path.split(docname)[1]
     env.domains["std"].data["labels"].pop(filename, None)
+    env.domains["std"].data["anonlabels"].pop(filename, None)
 
 
 def _update_post_node(node, options, arguments):
@@ -391,6 +395,7 @@ def process_posts(app, doctree):
             # if it is posting the document
             # ! this does not work for sections
             app.env.domains["std"].data["labels"][label] = (docname, label, title)
+            app.env.domains["std"].data["anonlabels"][label] = (docname, label)
 
         if section.parent is doctree:
             section_copy = section[0].deepcopy()
@@ -536,7 +541,7 @@ def process_postlist(app, doctree, docname):
 
 def missing_reference(app, env, node, contnode):
     target = node["reftarget"]
-    logging.warning(f"error, missing reference: {target}, {contnode}")
+    logging.debug(f"missing reference: {target}, {contnode}")
     return _missing_reference(app, target, node.get("refdoc"), contnode, node.get("refexplicit"))
 
 
