@@ -418,10 +418,10 @@ First Post
 World, hello again! This very first paragraph of the post will be used
 as excerpt in archives and feeds. Find out how to control how much is shown
 in `Post Excerpts and Images
-<https://ablog.readthedocs.org/manual/post-excerpts-and-images/>`_. Remember
+<https://ablog.readthedocs.org/manual/post-excerpts-and-images/>`__. Remember
 that you can refer to posts by file name, e.g. ``:ref:`first-post``` results
 in :ref:`first-post`. Find out more at `Cross-Referencing Blog Pages
-<https://ablog.readthedocs.org/manual/cross-referencing-blog-pages/>`_.
+<https://ablog.readthedocs.org/manual/cross-referencing-blog-pages/>`__.
 """
 
 
